local _, addon = ...
local TCL = addon.TomCatsLibs
local D = TCL.Data
local ContributionCollectorStates = TCL.Data.ContributionCollectorStates
local PlayerFaction = UnitFactionGroup("player")
--TCL.BulletinBoard.checkForUpdates("1.2.2", 1, {"VjWrxWeFqML","A2qGxbImAE","kWemgqIWpR"}, function(updateAvailable, latestVersion)
--    if (updateAvailable) then
--        print("|cFFFFCC00There is newer version of 'TomCat's Tours: Warfronts Command Center' available on Twitch and Curseforge|r")
--    end
--end);

local gameVersion = GetBuildInfo()

local function GetQuestChoiceInfo_Hook()
    if (gameVersion == "8.0.1") then
        local response = { D.flatten(D.QuestChoiceInfoMap[PlayerFaction]) }
        response[3] = 1
        return unpack(response)
    end
    return D.QuestChoiceInfoMap[PlayerFaction]
end

local function GetQuestChoiceOptionInfo_Hook(idx)
    local key = PlayerFaction .. idx
    for i = idx, idx + 2, 2 do
        local state = C_ContributionCollector.GetState(D.ContributionCollectorStates[i])
        if (state == 3) then state = 4 end
        key = key .. state
    end
    if (gameVersion == "8.0.1") then
        return D.flatten(D.QuestChoiceOptionInfoMap[key])
    end
    return D.QuestChoiceOptionInfoMap[key]
end

local function ToggleWarboard()
    GameTooltip:Hide()
    if (not WarboardQuestChoiceFrame) then
        WarboardQuestChoice_LoadUI();
    end
    if (WarboardQuestChoiceFrame and WarboardQuestChoiceFrame:IsShown()) then
        HideUIPanel(WarboardQuestChoiceFrame)
    else
        if (gameVersion == "8.0.1") then
            local GetQuestChoiceInfo_Orig = GetQuestChoiceInfo
            local GetQuestChoiceOptionInfo_Orig = GetQuestChoiceOptionInfo
            --noinspection GlobalCreationOutsideO
            GetQuestChoiceInfo = GetQuestChoiceInfo_Hook
            --noinspection GlobalCreationOutsideO
            GetQuestChoiceOptionInfo = GetQuestChoiceOptionInfo_Hook
            WarboardQuestChoiceFrame:TryShow()
            WarboardQuestChoiceFrame:TryShow()
            WarboardQuestChoiceFrame.hasPendingUpdate = false
            --noinspection GlobalCreationOutsideO
            GetQuestChoiceInfo = GetQuestChoiceInfo_Orig
            --noinspection GlobalCreationOutsideO
            GetQuestChoiceOptionInfo = GetQuestChoiceOptionInfo_Orig
        else
            local GetQuestChoiceInfo_Orig = C_QuestChoice.GetQuestChoiceInfo
            local GetQuestChoiceOptionInfo_Orig = C_QuestChoice.GetQuestChoiceOptionInfo
            C_QuestChoice.GetQuestChoiceInfo = GetQuestChoiceInfo_Hook
            C_QuestChoice.GetQuestChoiceOptionInfo = GetQuestChoiceOptionInfo_Hook
            WarboardQuestChoiceFrame:TryShow()
            WarboardQuestChoiceFrame.hasPendingUpdate = false
            C_QuestChoice.GetQuestChoiceInfo = GetQuestChoiceInfo_Orig
            C_QuestChoice.GetQuestChoiceOptionInfo = GetQuestChoiceOptionInfo_Orig
        end
    end
end

local function ShowTooltip(self)
    if (not (WarboardQuestChoiceFrame and WarboardQuestChoiceFrame:IsShown())) then
        GameTooltip:ClearLines()
        GameTooltip:SetOwner(self, "ANCHOR_LEFT")
        GameTooltip:SetText("TomCat's Tours:", 1, 1, 1)
        GameTooltip:AddLine("Warfronts Command Center", nil, nil, nil, true)
        if (gameVersion == "8.0.1") then
            local contributionID = C_ContributionCollector.GetManagedContributionsForCreatureID(D.ContributionCollectorCreatureIDs[PlayerFaction])
            local contributionName = C_ContributionCollector.GetName(contributionID)
            local state, stateAmount, timeOfNextStateChange = C_ContributionCollector.GetState(contributionID)
            local appearanceData = C_ContributionCollector.GetContributionAppearance(contributionID, state)
            if (appearanceData) then
                GameTooltip:AddLine(" ");
                GameTooltip:AddLine(contributionName, HIGHLIGHT_FONT_COLOR:GetRGB());
                local tooltipLine = appearanceData.tooltipLine;
                if tooltipLine then
                    if timeOfNextStateChange and appearanceData.tooltipUseTimeRemaining then
                        local time = math.max(timeOfNextStateChange - GetServerTime(), 60); -- Never display times below one minute
                        tooltipLine = tooltipLine:format(SecondsToTime(time, true, true, 1));
                    else
                        tooltipLine = tooltipLine:format(FormatPercentage(stateAmount));
                    end
                    GameTooltip:AddLine(tooltipLine, appearanceData.stateColor:GetRGB());
                end
            end
        else
            GameTooltip:AddLine(" ");
            ContributionCollectorPinMixin.AddContributionsToTooltip(
                self,
                GameTooltip,
                C_ContributionCollector.GetManagedContributionsForCreatureID(D.ContributionCollectorCreatureIDs[PlayerFaction])
            )
        end
        GameTooltip:Show()
    end
end

local function ADDON_LOADED(_, event, ...)
    local var1 = select(1, ...)
    if (var1 == addon.name) then
        TCL.Charms.Create({
            name = addon.name .. "MinimapButton",
            iconTexture = "Interface\\AddOns\\" .. addon.name .. "\\images\\commandcenter-icon",
            backgroundColor = {48/255,48/255,48/255,0.80 },
            handler_onclick = ToggleWarboard,
            title = "TomCat's Tours: Warfronts Command Center"
        }).tooltip = {
            Show = ShowTooltip,
            Hide = function()
                GameTooltip:Hide()
            end
        }
        TCL.Events.UnregisterEvent("ADDON_LOADED", ADDON_LOADED)
    end
end

TCL.Events.RegisterEvent("ADDON_LOADED", ADDON_LOADED)

if (TomCats and TomCats.Register) then
    TomCats:Register(
        {
            slashCommands = {
                {
                    command = "WCC TOGGLE",
                    desc = "Toggle Warfronts Command Center Window",
                    func = ToggleWarboard
                }
            },
            name = "Warfronts Command Center",
            version = "1.2.2"
        }
    )
end